![PyPI](https://img.shields.io/pypi/v/talondoc)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/talondoc)
[![GitHub Workflow Status](https://github.com/wenkokke/talondoc/actions/workflows/ci.yml/badge.svg)](https://github.com/wenkokke/talondoc/actions/workflows/ci.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/wenkokke/talondoc/master.svg)](https://results.pre-commit.ci/latest/github/wenkokke/talondoc/master)

# Sphinx extension for documenting Talon packages

See [the docs](https://wen.works/talondoc/).
